Default Model Fitting Function
default_model_func.RdFits a simple mean model that returns the mean of y_train. The predict() method returns this mean for all new observations.

default_model_func.RdFits a simple mean model that returns the mean of y_train. The predict() method returns this mean for all new observations.