Skip to contents

These demonstrations are computationally intensive and not built as vignettes. Use get_demo_path() to get the full path to a specific demo.

Usage

list_package_demos()

Value

Character vector of available demo Rmd file names

Examples

list_package_demos()
#> [1] "hmm_bootstrap_demo.Rmd"               
#> [2] "ms-varma-garch_diagnostics_report.Rmd"
#> [3] "ms-varma-garch_inference_demo.Rmd"    
#> [4] "multivar_garch_comparison.Rmd"        
#> [5] "portfolio-optimization.Rmd"