Perform the M-Step in Parallel (R Helper)
perform_m_step_parallel_r.Rd*** THIS FUNCTION IS NOW DEPRECATED. Using perform_m_step_r() instead *** This function is called once per EM iteration from C++. It uses the 'future' framework to estimate the parameters for all M states in parallel. Handles both univariate and multivariate models with proper parameter structuring.
Usage
perform_m_step_parallel_r(
y,
weights,
spec,
model_type,
diagnostics = NULL,
iteration = NULL,
verbose = FALSE
)