Plot Method for tsbs_benchmark
plot.tsbs_benchmark.RdCreates a visualization of benchmark results showing how runtime scales with the varying parameter across different bootstrap setups.
Usage
# S3 method for class 'tsbs_benchmark'
plot(x, log_scale = FALSE, show_points = TRUE, show_ribbon = TRUE, ...)